==> kari-0.23.tar.gz: kari-0.23/alyson/text.c <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1997, 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk/gtk.h>
#include "utils.h"
#include "neve.h"
#include "lisa.h"
#include "smg.h"
#include "text.h"

/* FIXME: this function and this file are poorly named.  It really
 * creates a sub-box in tiffani to hold a lisa.  lisa already does
 * much more than just text (e.g. horizontal rules, bullet points). */

/*****************************************************************************
 * function  : text_init
 * arguments : broswer window and tiffani widget
 * results   : 
 * purpose   : initializes the HTML rendering portion of a browser window
 * caveats   : 
 ***************************************************************************** */

void
text_init (BrowserWindow * cole,
	   GtkWidget * tiffani)
{
  GtkWidget *table;
  GtkWidget *vscrollbar;
  GtkWidget *sub_tiffani;

  sub_tiffani = gtk_vbox_new (FALSE, 10);
  gtk_container_border_width (GTK_CONTAINER (sub_tiffani), 10);
  gtk_box_pack_start (GTK_BOX (tiffani), sub_tiffani, TRUE, TRUE, 0);
  gtk_widget_show (sub_tiffani);

  table = gtk_table_new (2, 2, FALSE);
  gtk_table_set_row_spacing (GTK_TABLE (table), 0, 2);
  gtk_table_set_col_spacing (GTK_TABLE (table), 0, 2);
  gtk_box_pack_start (GTK_BOX (sub_tiffani), table, TRUE, TRUE, 0);
  gtk_widget_show (table);

  cole->lisa = gtk_lisa_new (NULL, NULL);
  GTK_WIDGET_SET_FLAGS (cole->lisa, GTK_CAN_FOCUS);
  gtk_table_attach_defaults (GTK_TABLE (table), cole->lisa, 0, 1, 0, 1);
  gtk_widget_show (cole->lisa);

  vscrollbar = gtk_vscrollbar_new (GTK_LISA (cole->lisa)->vadj);
  gtk_range_set_update_policy (GTK_RANGE (vscrollbar),
			       GTK_UPDATE_CONTINUOUS);
  gtk_table_attach (GTK_TABLE (table), vscrollbar, 1, 2, 0, 1,
		    GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_widget_show (vscrollbar);

}

==> kari-0.30.tar.gz: kari-0.30/alyson/text.c <==
/* YAWN, Yet Another Web Navigator */
/* Copyright (C) 1997, 1998, James Troup <jjtroup@comp.brad.ac.uk>
 *                     Lee Willis <lwillis@comp.brad.ac.uk> */

/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk/gtk.h>
#include "utils.h"
#include "neve.h"
#include "lisa.h"
#include "smg.h"
#include "text.h"

/* FIXME: this function and this file are poorly named.  It really
 * creates a sub-box in tiffani to hold a lisa.  lisa already does
 * much more than just text (e.g. horizontal rules, bullet points). */

/*****************************************************************************
 * function  : text_init
 * arguments : broswer window and tiffani widget
 * results   : 
 * purpose   : initializes the HTML rendering portion of a browser window
 * caveats   : 
 ***************************************************************************** */

void
text_init (BrowserWindow * paula,
	   GtkWidget * tiffani)
{
  GtkWidget *table;
  GtkWidget *vscrollbar;
  GtkWidget *sub_tiffani;

  sub_tiffani = gtk_vbox_new (FALSE, 10);
  gtk_container_border_width (GTK_CONTAINER (sub_tiffani), 10);
  gtk_box_pack_start (GTK_BOX (tiffani), sub_tiffani, TRUE, TRUE, 0);
  gtk_widget_show (sub_tiffani);

  table = gtk_table_new (2, 2, FALSE);
  gtk_table_set_row_spacing (GTK_TABLE (table), 0, 2);
  gtk_table_set_col_spacing (GTK_TABLE (table), 0, 2);
  gtk_box_pack_start (GTK_BOX (sub_tiffani), table, TRUE, TRUE, 0);
  gtk_widget_show (table);

  paula->lisa = gtk_lisa_new (NULL, NULL);
  GTK_WIDGET_SET_FLAGS (paula->lisa, GTK_CAN_FOCUS);
  gtk_table_attach_defaults (GTK_TABLE (table), paula->lisa, 0, 1, 0, 1);
  gtk_widget_show (paula->lisa);

  vscrollbar = gtk_vscrollbar_new (GTK_LISA (paula->lisa)->vadj);
  gtk_range_set_update_policy (GTK_RANGE (vscrollbar),
			       GTK_UPDATE_CONTINUOUS);
  gtk_table_attach (GTK_TABLE (table), vscrollbar, 1, 2, 0, 1,
		    GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
  gtk_widget_show (vscrollbar);

}

void
paula_set_title (BrowserWindow *paula, const char *title)
{

  if (strcmp (paula->title, "YAWN: you suck"))
    {
      free (paula->title);
      paula->title = xmalloc (strlen (title) + 1);
      strcpy (paula->title, title);
      gtk_window_set_title (GTK_WINDOW (paula->main_window), paula->title);
    }

}
